netapp_ontap.models.consistency_group_volume API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_volume`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupVolumeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupVolume object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `comment: str GET POST PATCH`

    A comment for the volume. Valid in POST or PATCH.

  `name: str GET POST PATCH`

    Volume name. The name of volume must start with an alphabetic character (a to z or A to Z) or an underscore (_). The name must be 197 or fewer characters in length for FlexGroup volumes, and 203 or fewer characters in length for all other types of volumes. Volume names must be unique within an SVM. Required on POST.

    Example: vol_cs_dept

  `nas: ConsistencyGroupNas GET POST PATCH`

    The nas field of the consistency_group_volume.

  `provisioning_options: ConsistencyGroupVolumeProvisioningOptions POST PATCH`

    Options that are applied to the operation.

  `qos: ConsistencyGroupQos GET POST PATCH`

    The qos field of the consistency_group_volume.

  `snapshot_policy: SnapshotPolicy GET POST PATCH`

    The snapshot policy for this volume.

  `space: ConsistencyGroupVolumeSpace GET POST PATCH`

    The space field of the consistency_group_volume.

  `tiering: ConsistencyGroupTiering GET POST PATCH`

    The tiering field of the consistency_group_volume.

  `uuid: str GET`

    Unique identifier for the volume. This corresponds to the instance-uuid that is exposed in the CLI and ONTAPI. It does not change due to a volume move.

    Example: 028baa66-41bd-11e9-81d5-00a0986138f7